@@ -36,7 +36,7 @@ class Backend(Component):
                     Projects.BACKEND,
                 ],
             ],
-            Images.PYTHON,
+            self.docker_image(Images.PYTHON),
             ".",
         )
 
@@ -51,7 +51,7 @@ class Backend(Component):
                 ],
                 ["poetry", "init", "-n", "--name", "backend"],
             ],
-            Images.PYTHON,
+            self.docker_image(Images.PYTHON),
             Projects.BACKEND,
         )
 
