@@ -10,7 +10,9 @@ log = logging.getLogger()
 class Reformat(Component):
     def create(self):
         multi_docker_run(
-            [["pip", "install", "black"], ["black", "."]], Images.PYTHON, Projects.BACKEND
+            [["pip", "install", "black"], ["black", "."]],
+            self.docker_image(Images.PYTHON),
+            Projects.BACKEND,
         )
 
     def update(self):
