@@ -33,11 +33,17 @@ class Dependencies(Component):
 
     def create(self):
         log.info("Installing frontend production dependencies")
-        docker_run(["yarn", "add", *self.dependencies], Images.NODE, Projects.FRONTEND)
+        docker_run(
+            ["yarn", "add", *self.dependencies],
+            self.docker_image(Images.NODE),
+            Projects.FRONTEND,
+        )
 
         log.info("Installing frontend dev dependencies")
         docker_run(
-            ["yarn", "add", "--dev", *self.dev_dependencies], Images.NODE, Projects.FRONTEND
+            ["yarn", "add", "--dev", *self.dev_dependencies],
+            self.docker_image(Images.NODE),
+            Projects.FRONTEND,
         )
 
         with use_dir(Projects.FRONTEND):
@@ -54,7 +60,7 @@ class Dependencies(Component):
     def update(self):
         self.call_phase(Phases.CREATE, force_create=True)
         log.info("Upgrading frontend dependencies")
-        docker_run(["yarn", "upgrade"], Images.NODE, Projects.FRONTEND)
+        docker_run(["yarn", "upgrade"], self.docker_image(Images.NODE), Projects.FRONTEND)
 
     @property
     def installed(self):
