@@ -38,7 +38,7 @@ class Mui(Component):
                 "@emotion/server",
                 "@emotion/styled",
             ],
-            Images.NODE,
+            self.docker_image(Images.NODE),
             Projects.FRONTEND,
         )
 
