@@ -27,21 +27,21 @@ class Eslint(Component):
         log.info("Installing eslint dev dependencies to frontend")
         docker_run(
             ["yarn", "add", "--dev", *self.dependencies],
-            Images.NODE,
+            self.docker_image(Images.NODE),
             Projects.FRONTEND,
         )
 
         log.info("Installing eslint plugins to frontend")
         docker_run(
             ["yarn", "add", "--dev", *self.plugins],
-            Images.NODE,
+            self.docker_image(Images.NODE),
             Projects.FRONTEND,
         )
 
         log.info("Installing eslint configs to frontend")
         docker_run(
             ["yarn", "add", "--dev", *self.configs],
-            Images.NODE,
+            self.docker_image(Images.NODE),
             Projects.FRONTEND,
         )
 
