@@ -17,7 +17,11 @@ log = logging.getLogger()
 class Prettier(Component):
     def create(self):
         log.info("Installing prettier dev dependency into the frontend project")
-        docker_run(["yarn", "add", "--dev", "prettier"], Images.NODE, Projects.FRONTEND)
+        docker_run(
+            ["yarn", "add", "--dev", "prettier"],
+            self.docker_image(Images.NODE),
+            Projects.FRONTEND,
+        )
 
     def update(self):
         self.call_phase(Phases.CREATE, force_create=True)
