@@ -12,7 +12,11 @@ log = logging.getLogger()
 class PrettyQuick(Component):
     def create(self):
         log.info("Installing pretty-quick into frontend project")
-        docker_run(["yarn", "add", "--dev", "pretty-quick"], Images.NODE, Projects.FRONTEND)
+        docker_run(
+            ["yarn", "add", "--dev", "pretty-quick"],
+            self.docker_image(Images.NODE),
+            Projects.FRONTEND,
+        )
 
         with use_dir(Projects.FRONTEND):
             log.info("Adding pretty-quick lint command")
