@@ -7,8 +7,10 @@ from click import style
 from ruamel.yaml import YAML
 import logging
 
+from semver import VersionInfo
+
 from .utils.files import find_nearest
-from .constants import config_file_name, __version__
+from .constants import config_file_name, __version__, ConfigDefaults
 
 
 yaml = YAML(typ="safe")
@@ -24,6 +26,7 @@ class Config(object):
         :param initial_data: When creating a new config file, add this to the file
         """
         try:
+            self.check_version()
             return Config.load()
         except FileNotFoundError:
             log.debug("Config file not found, creating a new one")
@@ -43,10 +46,12 @@ class Config(object):
             sys.exit(1)
 
         data = {"version": __version__}
+        data.update(ConfigDefaults)
         data.update(initial_data)
 
         Config.dump(Box(data))
 
+        self.check_version()
         return Config.load()
 
     @classmethod
@@ -72,3 +77,25 @@ class Config(object):
     @classmethod
     def delete(cls):
         os.remove(find_nearest(config_file_name))
+
+    @classmethod
+    def check_version(cls):
+        conf = cls.load()
+        conf_version = conf.get("version")
+        if conf_version is None:
+            return
+
+        current = VersionInfo.parse(__version__)
+        loaded = VersionInfo.parse(conf_version)
+
+        if current < loaded:
+            log.critical(
+                "Current version of Zygoat ({}) is older than project version ({}), exiting".format(
+                    style(current, bold=True, fg="red"), style(loaded, bold=True, fg="red")
+                )
+            )
+            sys.exit(1)
+
+        log.debug(f"Bumping project version flag from {loaded} to {current}")
+        conf.version = __version__
+        cls.dump(conf)
