@@ -21,7 +21,9 @@ project_dir_names = [
 
 Phases = Box([(t.upper(), t) for t in phase_function_names])
 Projects = Box([(t.upper(), t) for t in project_dir_names])
-Images = Box({"NODE": "node:latest", "PYTHON": "python:latest"})
+Images = Box({"NODE": "NODE", "PYTHON": "PYTHON"})
+
+ConfigDefaults = Box({"images": {"NODE": "node:latest", "PYTHON": "python:latest"}})
 
 FrontendUtils = os.path.join(Projects.FRONTEND, "zg_utils")
 
